@if "%ECHO_MODE%"=="" set ECHO_MODE=off
@echo %ECHO_MODE%
goto begin
@rem *************************************************************************

DfhlTest.bat: Test for DFHL

$Revision: 1.7 $
$Date: 2021/08/30 16:12:55 $
$Source: /BSK/BSK/DFHL/DfhlTest/DfhlTest.bat,v $

History:
V1.7  2021-08-30  BSK/HS
- Update DFHL from "..\bin\win32"
- More echo and comments updated
- Ask for erase of "[temp]\DfhlTest" at the end
V1.6  2012-10-22  BSK/HS
- Batch option /n added
2012-10-16  BSK/HS
- DFHL with /a /e /h /s /w
V1.5  2012-10-12  BSK/HS
- Ask for source dir
- Use "%temp%\DfhlTest" as dest dir
V1.4  2012-02-23  BSK/HS
- /i added
V1.3  2012-02-23  BSK/HS
- Check if "K:\CVSLocal\BSK\DFHL\Release\DFHL.exe" exist before update
- Write errorlevel to log file
- /v added
V1.2  2012-02-05  BSK/HS
- second pass with dest dir with hard links
V1.1  2012-02-03  BSK/HS
- Initial revision

@rem *************************************************************************
:begin
setlocal
set errlevel=0
pushd "%~dp0."
set _dt1_opt=
set _dt2_opt=
:optloop
if /I not "%~1"=="/NOP" goto end_nop
  set NOPAUSE=1
  goto optnext
:end_nop
if /I not "%~1"=="/I" goto end_i
  set _dt1_opt=%_dt1_opt% /i
  set _dt2_opt=%_dt2_opt% /i
  goto optnext
:end_i
if /I not "%~1"=="/N" goto end_n
  set _dt1_opt=%_dt1_opt% /n
  set _dt2_opt=%_dt2_opt% /n
  goto optnext
:end_n
if /I not "%~1"=="/V" goto end_v
  set _dt1_opt=%_dt1_opt% /v
  goto optnext
:end_v
goto optend
:optnext
  shift /1
  goto optloop
:optend
if not ''=='%1' goto tsthelp

@echo DfhlTest.bat: Make sure that you have sufficient test files in "SrcDir"
@echo   if you use this for test, or use e.g. "D:\tool\Multi2000".
@echo   Source is copied to "[temp]\DfhlTest", then DFHL is used for this
@echo   temp. dir.
set _dt_srcdir=
set /p "_dt_srcdir=Enter source dir (without ""): "
if "%_dt_srcdir%"=="" (
  @echo ?DfhlTest.bat: Aborted
  goto errlevelp
)
call :start "%_dt_srcdir%"
goto end

:tsthelp
if not ''=='%2' goto help
if '?'=='%1' goto help
if '-?'=='%1' goto help
if not '/?'=='%1' goto start
:help
  @echo DfhlTest.bat: Test for DFHL
  @echo Usage: DfhlTest [/noP] [/i] [/n] [/v] [SrcDir]
  @echo e.g.: DfhlTest /i /n "D:\tool\Multi2000"
  @echo (if you have enough free space on C: and enough time)
  goto errlevelp


@rem *************************************************************************
:start
if not exist "%~1\*.*" (
  @echo ?%~nx0: "%~1" not found
  goto errlevelp
)


for %%N in (DFHL.exe) do @echo "%%~N"  %%~tN  %%~zN
if exist "%~dp0..\bin\win32\DFHL.exe" (
  update32.exe "%~dp0..\bin\win32\DFHL.exe" . /a /p
)

if exist "%temp%\DfhlTest\*.*" echo rmdir /s /q "[temp]\DfhlTest" ...
rmdir /s /q "%temp%\DfhlTest" >nul 2>&1
if exist "%temp%\DfhlTest\*.*" (
  @echo ?%~nx0: Can't erase [temp]\DfhlTest
  goto errlevelp
)
@echo xcopy "%~1\*.*" "[temp]\DfhlTest" ...
xcopy "%~1\*.*" "%temp%\DfhlTest" /S /E /I /Q /H /R /K >nul
if errorlevel 1 (
  @echo ?%~nx0: xcopy error
  goto errlevelp
)
call :GetDateTime
set "_dt_log_name=Dfhl_%_dt_date8%_%_dt_time4%.log"

@echo ------------------------------------------------------------------------ |gnu_tee -a "%_dt_log_name%" >>DfhlTest.log
@echo Log see "Dfhl_%_dt_date8%_%_dt_time4%.log" and "\DfhlTest.log" in "%CD%"
for %%N in (DFHL.exe) do @echo "%%~N"  %%~tN  %%~zN |gnu_tee -a DfhlTest.log|gnu_tee -a "%_dt_log_name%"
@echo Start [%_dt_date% %_dt_time%] "%~nx0" %_dt1_opt% "%~1" on "%COMPUTERNAME%" |gnu_tee -a DfhlTest.log|gnu_tee -a "%_dt_log_name%"
@echo First test with dest dir without any hard links (after xcopy) |gnu_tee -a DfhlTest.log|gnu_tee -a "%_dt_log_name%"
@echo .\DFHL.exe /a /e /h /l /r /s /t /w %_dt1_opt% "%temp%\DfhlTest" |gnu_tee -a DfhlTest.log|gnu_tee -a "%_dt_log_name%"
.\DFHL.exe /a /e /h /l /r /s /t /w %_dt1_opt% "%temp%\DfhlTest" >>"%_dt_log_name%" 2>&1
@echo errorlevel=%errorlevel% >>"%_dt_log_name%"
if errorlevel 1 (
  @echo ?%~nx0: DFHL error |gnu_tee -a DfhlTest.log
  goto errlevelp
)
set _dt_starttime=%_dt_time_s%
call :GetDateTime
set /A "_dt_deltat_nowarn=%_dt_time_s% - %_dt_starttime%"

@echo Done1 [%_dt_date% %_dt_time%] DeltaT=%_dt_deltat_nowarn%s |gnu_tee -a DfhlTest.log|gnu_tee -a "%_dt_log_name%"

@echo Second test with dest dir with hard links (after DFHL) |gnu_tee -a DfhlTest.log|gnu_tee -a "%_dt_log_name%"
@echo .\DFHL.exe /a /e /h /l /r /s /t /w %_dt2_opt% "%temp%\DfhlTest" |gnu_tee -a DfhlTest.log|gnu_tee -a "%_dt_log_name%"
.\DFHL.exe /a /e /h /l /r /s /t /w %_dt2_opt% "%temp%\DfhlTest" >>"%_dt_log_name%" 2>&1
@echo errorlevel=%errorlevel% >>"%_dt_log_name%"
if errorlevel 1 (
  @echo ?%~nx0: DFHL error |gnu_tee -a DfhlTest.log
  goto errlevelp
)
set _dt_starttime=%_dt_time_s%
call :GetDateTime
set /A "_dt_deltat_nowarn=%_dt_time_s% - %_dt_starttime%"

@echo Done2 [%_dt_date% %_dt_time%] DeltaT=%_dt_deltat_nowarn%s |gnu_tee -a DfhlTest.log|gnu_tee -a "%_dt_log_name%"

@rem check result with ctts
if exist s:\ctts.exe s:\ctts.exe "%temp%\DfhlTest" >>"%_dt_log_name%"
@echo Done (see Dfhl*.log and compare "%~1" with "[temp]\DfhlTest")
if not "%NOPAUSE%"=="" (
  @echo Erase "[temp]\DfhlTest" after compare
  goto endd3
)
set _yn=
set /P "_yn=Erase '[temp]\DfhlTest' (Yn): "
if /I "%_yn%"=="N" goto endd3
if exist "%temp%\DfhlTest\*.*" echo rmdir /s /q "[temp]\DfhlTest" ...
rmdir /s /q "%temp%\DfhlTest" >nul 2>&1
if exist "%temp%\DfhlTest\*.*" (
  @echo ?%~nx0: Can't erase [temp]\DfhlTest
  goto errlevelp
)
:endd3
ping -n 4 127.0.0.1 >nul 2>&1
goto end


@rem **************************************************************************
:GetDateTime
set _dt_time=%TIME%
set _dt_date=%DATE%
set "_dt_time=%_dt_time: =0%"
set "_dt_date=%_dt_date: =0%"
set "_dt_time6=%_dt_time::=%"
set "_dt_time6=%_dt_time6:~0,6%"
set "_dt_time_h=%_dt_time6:~0,2%"
set /A "_dt_time_h=1%_dt_time_h%-100"
set "_dt_time_m=%_dt_time6:~2,2%"
set /A "_dt_time_m=1%_dt_time_m%-100"
set "_dt_time_s=%_dt_time6:~4,2%"
set /A "_dt_time_s=1%_dt_time_s%-100+(60*%_dt_time_m%)+(60*60*%_dt_time_h%)"
set "_dt_time4=%_dt_time6:~0,4%"
set "_dt_temp=%_dt_date:-=%"
if "%_dt_temp%"=="%_dt_date%" (
  @echo ?%~nx0: Wrong date format [must be ISO format YYYY-MM-DD]
  pause
  popd
  exit /b 1
)
set "_dt_date8=%_dt_temp%"
goto eof


@rem **************************************************************************
:errlevelp
  set errlevel=1
:: pause
if "%NOPAUSE%"=="" pause
:end
popd
exit /b %errlevel%
:eof
