/*!***************************************************************************

\file wrn_norm.h
\brief <b>Warnungen fr Applikationsmodule einstellen</b>

\copyright (c) 2000-2015 BSK Datentechnik GmbH

\author Hans Schmidts

$Revision: 1.14 $
$Date: 2015/07/17 16:10:07 $
$Source: /BSK/C/include/wrn_norm.h,v $

*//***************************************************************************

History:
V1.14  2015-07-17  BSK/HS
- Doxygen header
- Kommentare mit Umlauten usw. und Tippfehler korrigiert
V1.13  2013-05-22  BSK/HS
- disable:4703 for MS-VS2012 added
V1.12  2006-01-06  BSK/HS
- disable:4700 if NDEBUG (for MSVC6-pro)
V1.11  2005-12-09  BSK/HS
- disable:4244 4710 4711 global in wrn_inc.h
V1.10  2003-09-09  BSK/HS
- Kommentare zu DUMMY_INIT_LOCAL_VARIABLE usw. ergnzt
2003-04-25..2000-07-06 Siehe CVS
*/
#define _WRN_NORM_H

#if (defined _MSC_VER) && (_MSC_VER>=1200) /* Ab MSVS 6.0=Compiler 12.00 */
  /* Erst mal standard Einstellungen restaurieren */
  #ifdef _WRN_PUSH
    #undef _WRN_PUSH
    #pragma warning(pop)
  #endif
  /* .. dann alles Ntige abschalten */
  #if (defined __cplusplus) && !(defined NDEBUG)
   #pragma warning(disable:4127)/* conditional expression is constant
                                   (caused e.g. by ASSERT from AFX.H) */
  #endif
  #pragma warning(disable:4514) /* unreferenced inline/local function has
                                   been removed */
  #ifdef NDEBUG
    #pragma warning(disable:4700) /* local variable used without having been
                                     initialized */
    #pragma warning(disable:4701) /* local variable may be used without
                                     having been initialized */
    #pragma warning(disable:4703) /* potentially uninitialized local pointer
                                     variable '...' used */
  #endif /* NDEBUG */
  /* .. und schlielich diesen Zustand speichern um nach individuellen
     nderungen leicht, z.B. mit wrn_pop.h, die normalen Einstellungen
     wiederherstellen zu knnen. */
  #define _WRN_PUSH
  #pragma warning(push)
#elif defined __TURBOC__
  #pragma warn .nak             /* restore "Non-ANSI keyword"-warning */
#endif


/***************************************************************************

DUMMY_????_LOCAL_VARIABLE: Unterdrckung unsinniger Warnungen

Anm.:
- Die Makros drfen nur dort verwendet werden wo sicher ist, dass die
  Variable bei Benutzung nicht wirklich uninitialisiert ist! Z.B. wenn
  das durch eine andere Statusvariable sichergestellt ist, oder wenn
  der Zweig, der keine Initialisierung enthlt, z.B. mit longjmp
  (vor der Verwendung) verlassen wird.
- Damit die Warnung in der Debug-Version gezielt unterdrckt werden
  kann, ist die entsprechende Warnung aktiv und die Variable wird mit
  dem selben Testmuster initialisiert, mit dem die lokalen Variablen von
  MSVC sowieso gefllt werden.
- Damit die Warnung in der Release-Version nicht kommt, ohne dass
  unntiger Code zur Initialisierung erzeugt wird, ist bei der Release-
  Version die Warnung generell ausgeschaltet. Es ist also auf jeden Fall
  ntig, alle Projekte zumindest gelegentlich als Debug-Version zu
  bersetzen!
*/


/***************************************************************************

DUMMY_INIT_LOCAL_VARIABLE: Fr einfach Typen bis 4 byte (char, int, ..)

V: Variable; t: Typ; z.B. DUMMY_INIT_LOCAL_VARIABLE(iCount,int);
*/
#ifdef NDEBUG
  #define DUMMY_INIT_LOCAL_VARIABLE(V,t)    ((void)0)
#else
  #define DUMMY_INIT_LOCAL_VARIABLE(V,t) \
    (V)=(t)(((unsigned long)((t)-1L))&0xCCCCCCCCUL)
#endif


/***************************************************************************

DUMMY_FILL_LOCAL_VARIABLE: Fr komplexe Typen (benutzt memset)

V: Variable; z.B. DUMMY_FILL_LOCAL_VARIABLE(stValue);
*/
#ifdef NDEBUG
  #define DUMMY_FILL_LOCAL_VARIABLE(V)      ((void)0)
#else
  #define DUMMY_FILL_LOCAL_VARIABLE(V)      memset(&(V),0xCC,sizeof(V))
#endif


/***************************************************************************

Macros used to eliminate compiler warning generated when formal
parameters or local variables are not declared.

Use DBG_UNREFERENCED_PARAMETER() when a parameter is not yet
referenced but will be once the module is completely developed.

Use DBG_UNREFERENCED_LOCAL_VARIABLE() when a local variable is not yet
referenced but will be once the module is completely developed.

Use UNREFERENCED_PARAMETER() if a parameter will never be referenced.

DBG_UNREFERENCED_PARAMETER and DBG_UNREFERENCED_LOCAL_VARIABLE will
eventually be made into a null macro to help determine whether there
is unfinished work.
*/
#ifndef UNREFERENCED_PARAMETER
  /* dummy use to avoid warning */
  #ifdef _MSC_VER
    #define UNREFERENCED_PARAMETER(P)           (P)
  #else
    #define UNREFERENCED_PARAMETER(P)           ((void)(P))
    /* (this variant tested with TC) */
  #endif
#endif

#ifdef NDEBUG
  /* P not used so the warning will be generated to remind you that there
     is unfinished work */
  #ifdef DBG_UNREFERENCED_PARAMETER
    #undef DBG_UNREFERENCED_PARAMETER
  #endif
  #define DBG_UNREFERENCED_PARAMETER(P)         ((void)0)
  #ifdef DBG_UNREFERENCED_LOCAL_VARIABLE
    #undef DBG_UNREFERENCED_LOCAL_VARIABLE
  #endif
  #define DBG_UNREFERENCED_LOCAL_VARIABLE(P)    ((void)0)
#else /* DEBUG */
  /* dummy use so you are not bothered with warnings due to unfinished work,
     which is deferred explicit */
  #ifndef DBG_UNREFERENCED_PARAMETER
    #define DBG_UNREFERENCED_PARAMETER(P)       UNREFERENCED_PARAMETER(P)
  #endif
  #ifndef DBG_UNREFERENCED_LOCAL_VARIABLE
    #define DBG_UNREFERENCED_LOCAL_VARIABLE(V)  UNREFERENCED_PARAMETER(V)
  #endif
#endif /* DEBUG */


/* EOF wrn_norm.h */
